@@ -100,12 +100,12 @@ DiffCorr <- function(exp, obs, ref, N.eff = NA, time_dim = 'sdate',
     if (!is.numeric(N.eff)) stop("Parameter 'N.eff' must be numeric.")
     if (!all(names(dim(N.eff)) %in% names(dim(obs))) |
         any(dim(obs)[match(names(dim(N.eff)), names(dim(obs)))] != dim(N.eff))) {
-      stop(paste0('If parameter "N.eff" is provided with an array, it must ',
-                  'have the same dimensions as "obs" except "time_dim".'))
+      stop('If parameter "N.eff" is provided with an array, it must ',
+           'have the same dimensions as "obs" except "time_dim".')
     }
   } else if (any((!is.na(N.eff) & !is.numeric(N.eff)) | length(N.eff) != 1)) {
-    stop(paste0('Parameter "N.eff" must be NA, a numeric, or an array with ',
-                'the same dimensions as "obs" except "time_dim".'))
+    stop('Parameter "N.eff" must be NA, a numeric, or an array with ',
+         'the same dimensions as "obs" except "time_dim".')
   }
   ## time_dim
   if (!is.character(time_dim) | length(time_dim) != 1)
@@ -132,9 +132,10 @@ DiffCorr <- function(exp, obs, ref, N.eff = NA, time_dim = 'sdate',
     name_ref <- name_ref[-which(name_ref == memb_dim)]
   }
   if (length(name_exp) != length(name_obs) | length(name_exp) != length(name_ref) |
-      !identical(dim(exp)[name_exp], dim(obs)[name_obs]) | !identical(dim(exp)[name_exp], dim(ref)[name_ref])) {
-    stop(paste0("Parameter 'exp', 'obs', and 'ref' must have same length of ",
-                "all dimensions except 'memb_dim'."))
+      !identical(dim(exp)[name_exp], dim(obs)[name_obs]) |
+      !identical(dim(exp)[name_exp], dim(ref)[name_ref])) {
+    stop("Parameter 'exp', 'obs', and 'ref' must have same length of ",
+         "all dimensions except 'memb_dim'.")
   }
   ## method
   if (!method %in% c("pearson", "spearman")) {
@@ -175,13 +176,12 @@ DiffCorr <- function(exp, obs, ref, N.eff = NA, time_dim = 'sdate',
   # Calculate ensemble means
   dim_exp <- dim(exp)
   dim_ref <- dim(ref)
-  dim_obs <- dim(obs)
 
   if (!is.null(memb_dim)) {
     exp_memb_dim_ind <- which(names(dim_exp) == memb_dim)
     ref_memb_dim_ind <- which(names(dim_ref) == memb_dim)
-    exp <- apply(exp, c(1:length(dim_exp))[-exp_memb_dim_ind], mean, na.rm = FALSE)
-    ref <- apply(ref, c(1:length(dim_ref))[-ref_memb_dim_ind], mean, na.rm = FALSE)
+    exp <- apply(exp, c(seq_along(dim_exp))[-exp_memb_dim_ind], mean, na.rm = FALSE)
+    ref <- apply(ref, c(seq_along(dim_ref))[-ref_memb_dim_ind], mean, na.rm = FALSE)
     if (is.null(dim(exp))) exp <- array(exp, dim = c(dim_exp[time_dim]))
     if (is.null(dim(ref))) ref <- array(ref, dim = c(dim_ref[time_dim]))
   }
@@ -232,12 +232,16 @@ DiffCorr <- function(exp, obs, ref, N.eff = NA, time_dim = 'sdate',
       N.eff <- .Eno(x = obs, na.action = na.pass) ## effective degrees of freedom
     }
 
-    # Significance with one-sided or two-sided test for equality of dependent correlation coefficients (Steiger, 1980)
+    # Significance with one-sided or two-sided test for equality of dependent 
+    # correlation coefficients (Steiger, 1980)
     r12 <- cor.exp
     r13 <- cor.ref
     r23 <- cor(exp, ref)
     R <- (1 - r12 * r12 - r13 * r13 - r23 * r23) + 2 * r12 * r13 * r23
-    t <- (r12 - r13) * sqrt((N.eff - 1) * (1 + r23) / (2 * ((N.eff - 1) / (N.eff - 3)) * R + 0.25 * (r12 + r13)^2 * (1 - r23)^3))
+    t <- (r12 - r13) * 
+         sqrt((N.eff - 1) * (1 + r23) / 
+              (2 * ((N.eff - 1) / (N.eff - 3)) * R + 
+               0.25 * (r12 + r13)^2 * (1 - r23)^3))
     
     if (test.type == 'one-sided') {
       
@@ -251,7 +255,7 @@ DiffCorr <- function(exp, obs, ref, N.eff = NA, time_dim = 'sdate',
         output$p.val <- p.value
       }
       if (sign) {
-        output$sign <- ifelse(!is.na(p.value) & p.value <= alpha & output$diff.corr > 0, TRUE, FALSE)
+        output$sign <- !is.na(p.value) & p.value <= alpha & output$diff.corr > 0
       }
 
     } else if (test.type == 'two-sided') {
@@ -266,7 +270,7 @@ DiffCorr <- function(exp, obs, ref, N.eff = NA, time_dim = 'sdate',
         output$p.val <- p.value
       }
       if (sign) {
-        output$sign <- ifelse(!is.na(p.value) & p.value <= alpha / 2, TRUE, FALSE)
+        output$sign <- !is.na(p.value) & p.value <= alpha / 2
       }
  
     } else {
@@ -288,7 +292,8 @@ DiffCorr <- function(exp, obs, ref, N.eff = NA, time_dim = 'sdate',
       ref <- ref[!nna]
 
       output <- .diff.corr(exp = exp, obs = obs, ref = ref, method = method, 
-                           N.eff = N.eff, alpha = alpha, pval = pval, sign = sign, test.type = test.type)
+                           N.eff = N.eff, alpha = alpha, pval = pval, sign = sign, 
+                           test.type = test.type)
       
     } else if (handle.na == 'return.na') {
       # Data contain NA, return NAs directly without passing to .diff.corr
@@ -303,7 +308,8 @@ DiffCorr <- function(exp, obs, ref, N.eff = NA, time_dim = 'sdate',
     
   } else { ## There is no NA  
     output <- .diff.corr(exp = exp, obs = obs, ref = ref, method = method, 
-                         N.eff = N.eff, alpha = alpha, pval = pval, sign = sign, test.type = test.type)
+                         N.eff = N.eff, alpha = alpha, pval = pval, sign = sign, 
+                         test.type = test.type)
   }
 
   return(output)
