@@ -49,39 +49,42 @@
 #'------------------\cr\cr  
 #'RMSE error for a number of experiments and along lead-time: (nexp, nltime)
 #'
+#'@return
+#'No return value, called for side effects.
+#'
 #'@examples
-#'# Load sample data as in Load() example:
-#'example(Load)
-#'clim <- Clim(sampleData$mod, sampleData$obs)
-#'ano_exp <- Ano(sampleData$mod, clim$clim_exp)
-#'ano_obs <- Ano(sampleData$obs, clim$clim_obs)
-#'runmean_months <- 12
-#'smooth_ano_exp <- Smoothing(data = ano_exp, runmeanlen = runmean_months)
-#'smooth_ano_obs <- Smoothing(data = ano_obs, runmeanlen = runmean_months)
-#'dim_to_mean <- 'member'  # mean along members
-#'required_complete_row <- 'ftime'  # discard startdates for which there are NA leadtimes
-#'leadtimes_per_startdate <- 60
-#'rms <- RMS(MeanDims(smooth_ano_exp, dim_to_mean), 
-#'           MeanDims(smooth_ano_obs, dim_to_mean), 
-#'           comp_dim = required_complete_row, dat_dim = 'dataset',
-#'           limits = c(ceiling((runmean_months + 1) / 2), 
-#'           leadtimes_per_startdate - floor(runmean_months / 2)))
-#'smooth_ano_exp_m_sub <- smooth_ano_exp - InsertDim(MeanDims(smooth_ano_exp, 'member', 
-#'                                                            na.rm = TRUE), 
-#'                                                   posdim = 3, 
-#'                                                   lendim = dim(smooth_ano_exp)['member'], 
-#'                                                   name = 'member')
-#'suppressWarnings({
-#'spread <- Spread(smooth_ano_exp_m_sub, compute_dim = c('member', 'sdate'))
-#'})
-#'#Combine rms outputs into one array 
-#'rms_combine <- abind::abind(rms$conf.lower, rms$rms, rms$conf.upper, along = 0)
-#'rms_combine <- Reorder(rms_combine, c(2, 3, 1, 4))
-#'  \donttest{
-#'Plot2VarsVsLTime(InsertDim(rms_combine[, , , ], 1, 1), Reorder(spread$sd, c(1, 3, 2)), 
-#'                 toptitle = 'RMSE and spread', monini = 11, freq = 12, 
-#'                 listexp = c('CMIP5 IC3'), listvar = c('RMSE', 'spread'))
-#'  }
+#' # Load sample data as in Load() example:
+#' example(LoadSampleData)
+#' clim <- Clim(sampleData$mod, sampleData$obs)
+#' ano_exp <- Ano(sampleData$mod, clim$clim_exp)
+#' ano_obs <- Ano(sampleData$obs, clim$clim_obs)
+#' runmean_months <- 12
+#' smooth_ano_exp <- Smoothing(data = ano_exp, runmeanlen = runmean_months)
+#' smooth_ano_obs <- Smoothing(data = ano_obs, runmeanlen = runmean_months)
+#' dim_to_mean <- 'member'  # mean along members
+#' required_complete_row <- 'ftime'  # discard startdates for which there are NA leadtimes
+#' leadtimes_per_startdate <- 60
+#' rms <- RMS(MeanDims(smooth_ano_exp, dim_to_mean), 
+#'            MeanDims(smooth_ano_obs, dim_to_mean), 
+#'            comp_dim = required_complete_row, dat_dim = 'dataset',
+#'            limits = c(ceiling((runmean_months + 1) / 2), 
+#'            leadtimes_per_startdate - floor(runmean_months / 2)))
+#' smooth_ano_exp_m_sub <- smooth_ano_exp - InsertDim(MeanDims(smooth_ano_exp, 'member', 
+#'                                                             na.rm = TRUE), 
+#'                                                    posdim = 3, 
+#'                                                    lendim = dim(smooth_ano_exp)['member'], 
+#'                                                    name = 'member')
+#' suppressWarnings({
+#' spread <- Spread(smooth_ano_exp_m_sub, compute_dim = c('member', 'sdate'))
+#' })
+#' #Combine rms outputs into one array 
+#' rms_combine <- abind::abind(rms$conf.lower, rms$rms, rms$conf.upper, along = 0)
+#' rms_combine <- Reorder(rms_combine, c(2, 3, 1, 4))
+#' \donttest{
+#' Plot2VarsVsLTime(InsertDim(rms_combine[, , , ], 1, 1), Reorder(spread$sd, c(1, 3, 2)), 
+#'                  toptitle = 'RMSE and spread', monini = 11, freq = 12, 
+#'                  listexp = c('CMIP5 IC3'), listvar = c('RMSE', 'spread'))
+#' }
 #'
 #'@importFrom grDevices png jpeg postscript pdf svg bmp tiff postscript dev.cur dev.new dev.off
 #'@importFrom stats ts 
@@ -110,11 +113,11 @@ Plot2VarsVsLTime <- function(var1, var2, toptitle = '', ytitle = '', monini = 1,
   nvars <- 2
 
   if (length(dim(var1)) != length(dim(var2))) { 
-    print("the two input variables should have the same dimensions")
+    message("the two input variables should have the same dimensions")
     stop()
   }
   if (length(dim(var1)) >= 4) { 
-    print("dimensions of input variables should be 3")
+    message("dimensions of input variables should be 3")
     stop()
   }
   nleadtime <- dim(var1)[3]
@@ -193,6 +196,8 @@ Plot2VarsVsLTime <- function(var1, var2, toptitle = '', ytitle = '', monini = 1,
   }
 
   # Load the user parameters
+  oldpar <- par(no.readonly = TRUE)
+  on.exit(par(oldpar))
   par(userArgs)
 
   if (biglab) {
