@@ -51,19 +51,22 @@
 #'  srt tck tcl usr xaxp xaxs xaxt xlog xpd yaxp yaxs yaxt ylbias ylog \cr
 #'  For more information about the parameters see `par`.
 #'
+#'@return
+#'No return value, called for side effects.
+#'
 #'@examples
-#'# Load sample data as in Load() example:
-#'example(Load)
-#'clim <- Clim(sampleData$mod, sampleData$obs)
-#'ano_exp <- Ano(sampleData$mod, clim$clim_exp)
-#'ano_obs <- Ano(sampleData$obs, clim$clim_obs)
-#'smooth_ano_exp <- Smoothing(ano_exp, time_dim = 'ftime', runmeanlen = 12)
-#'smooth_ano_obs <- Smoothing(ano_obs, time_dim = 'ftime', runmeanlen = 12)
-#'smooth_ano_exp <- Reorder(smooth_ano_exp, c(2, 3, 4, 1))
-#'smooth_ano_obs <- Reorder(smooth_ano_obs, c(2, 3, 4, 1))
-#'PlotAno(smooth_ano_exp, smooth_ano_obs, startDates, 
-#'        toptitle = paste('smoothed anomalies'), ytitle = c('K', 'K', 'K'), 
-#'        legends = 'ERSST', biglab = FALSE)
+#' # Load sample data as in Load() example:
+#' example(LoadSampleData)
+#' clim <- Clim(sampleData$mod, sampleData$obs)
+#' ano_exp <- Ano(sampleData$mod, clim$clim_exp)
+#' ano_obs <- Ano(sampleData$obs, clim$clim_obs)
+#' smooth_ano_exp <- Smoothing(ano_exp, time_dim = 'ftime', runmeanlen = 12)
+#' smooth_ano_obs <- Smoothing(ano_obs, time_dim = 'ftime', runmeanlen = 12)
+#' smooth_ano_exp <- Reorder(smooth_ano_exp, c(2, 3, 4, 1))
+#' smooth_ano_obs <- Reorder(smooth_ano_obs, c(2, 3, 4, 1))
+#' PlotAno(smooth_ano_exp, smooth_ano_obs, startDates, 
+#'         toptitle = paste('smoothed anomalies'), ytitle = c('K', 'K', 'K'), 
+#'         legends = 'ERSST', biglab = FALSE)
 #'
 #'@importFrom grDevices dev.cur dev.new dev.off 
 #'@importFrom stats ts
@@ -105,7 +108,7 @@ PlotAno <- function(exp_ano, obs_ano = NULL, sdates, toptitle = rep('', 15),
       stop("4 dim needed : c(nexp/nobs, nmemb, nsdates, nltime)") 
     }
     if (dim(obs_ano)[3] != nsdates | dim(obs_ano)[4] != nleadtime ) {
-      stop("obs and exp must have same number of sdates & ltimes") 
+      stop("obs and exp must have the same number of sdates & ltimes") 
     }
   } else {
     nobs <- 0
@@ -180,6 +183,8 @@ PlotAno <- function(exp_ano, obs_ano = NULL, sdates, toptitle = rep('', 15),
 
 
     # Load the user parameters
+    oldpar <- par(no.readonly = TRUE)
+    on.exit(par(oldpar))
     par(userArgs)
 
     if (biglab) {
