@@ -40,14 +40,17 @@
 #'  lheight ljoin lmitre mar mex mfcol mfrow mfg mkh oma omd omi page pch plt 
 #'  smo srt tck usr xaxp xaxs xaxt xlog xpd yaxp yaxs yaxt ylbias ylog \cr
 #'  For more information about the parameters see `par`.
+#'  
+#'@return
+#'No return value, called for side effects.
 #'
 #'@examples
-#'# Load sample data as in Load() example:
-#'example(Load)
-#'clim <- Clim(sampleData$mod, sampleData$obs)
-#'PlotClim(clim$clim_exp, clim$clim_obs, toptitle = paste('climatologies'), 
-#'         ytitle = 'K', monini = 11, listexp = c('CMIP5 IC3'), 
-#'         listobs = c('ERSST'), biglab = FALSE, fileout = NULL)
+#' # Load sample data as in Load() example:
+#' example(LoadSampleData)
+#' clim <- Clim(sampleData$mod, sampleData$obs)
+#' PlotClim(clim$clim_exp, clim$clim_obs, toptitle = paste('climatologies'), 
+#'          ytitle = 'K', monini = 11, listexp = c('CMIP5 IC3'), 
+#'          listobs = c('ERSST'), biglab = FALSE, fileout = NULL)
 #'
 #'@importFrom grDevices dev.cur dev.new dev.off 
 #'@importFrom stats ts
@@ -151,6 +154,8 @@ PlotClim <- function(exp_clim, obs_clim = NULL, toptitle = '', ytitle = '',
   }
 
   # Load the user parameters
+  oldpar <- par(no.readonly = TRUE)
+  on.exit(par(oldpar))
   par(userArgs)
 
   if (biglab) {
