@@ -225,35 +225,15 @@
 #'}
 #'
 #'@examples
-#'# See examples on Load() to understand the first lines in this example
-#'  \dontrun{
-#'data_path <- system.file('sample_data', package = 's2dv')
-#'expA <- list(name = 'experiment', path = file.path(data_path,
-#'             'model/$EXP_NAME$/$STORE_FREQ$_mean/$VAR_NAME$_3hourly',
-#'             '$VAR_NAME$_$START_DATE$.nc'))
-#'obsX <- list(name = 'observation', path = file.path(data_path,
-#'             '$OBS_NAME$/$STORE_FREQ$_mean/$VAR_NAME$',
-#'             '$VAR_NAME$_$YEAR$$MONTH$.nc'))
+#' startDates <- c('19851101', '19901101', '19951101', '20001101', '20051101')
+#' sampleData <- LoadSampleData(startDates,
+#'                              leadtimemin = 1,
+#'                              leadtimemax = 4,
+#'                              output = 'lonlat')
+#' PlotEquiMap(sampleData$mod[1, 1, 1, 1, , ], sampleData$lon, sampleData$lat, 
+#'             toptitle = 'Predicted sea surface temperature for Nov 1960 from 1st Nov',
+#'             title_scale = 0.5)
 #'
-#'# Now we are ready to use Load().
-#'startDates <- c('19851101', '19901101', '19951101', '20001101', '20051101')
-#'sampleData <- Load('tos', list(expA), list(obsX), startDates,
-#'                   leadtimemin = 1, leadtimemax = 4, output = 'lonlat',
-#'                   latmin = 27, latmax = 48, lonmin = -12, lonmax = 40)
-#'  }
-#'  \dontshow{
-#'startDates <- c('19851101', '19901101', '19951101', '20001101', '20051101')
-#'sampleData <- s2dv:::.LoadSampleData('tos', c('experiment'),
-#'                                                c('observation'), startDates,
-#'                                                leadtimemin = 1,
-#'                                                leadtimemax = 4,
-#'                                                output = 'lonlat',
-#'                                                latmin = 27, latmax = 48,
-#'                                                lonmin = -12, lonmax = 40)
-#'  }
-#'PlotEquiMap(sampleData$mod[1, 1, 1, 1, , ], sampleData$lon, sampleData$lat, 
-#'            toptitle = 'Predicted sea surface temperature for Nov 1960 from 1st Nov',
-#'            title_scale = 0.5)
 #'@import graphics maps
 #'@importFrom grDevices dev.cur dev.new dev.off gray
 #'@importFrom stats cor
@@ -1058,6 +1038,8 @@ PlotEquiMap <- function(var, lon, lat, varu = NULL, varv = NULL,
   }
   plot.new()
   # Load the user parameters
+  oldpar <- par(no.readonly = TRUE)
+  on.exit(par(oldpar))
   par(userArgs)
   par(mar = margins, cex.main = cex_title, cex.axis = cex_axes_labels,
       mgp = c(0, spaceticklab, 0), las = 0)
