@@ -167,13 +167,12 @@
 #'}
 #'
 #'@examples
-#'data <- matrix(rnorm(100 * 50), 100, 50)
-#'x <- seq(from = 0, to = 360, length.out = 100)
-#'y <- seq(from = -90, to = 90, length.out = 50)
-#'  \dontrun{
-#'PlotStereoMap(data, x, y, latlims = c(60, 90), brks = 50,
-#'              toptitle = "This is the title")
-#' }
+#' data <- matrix(rnorm(100 * 50), 100, 50)
+#' x <- seq(from = 0, to = 360, length.out = 100)
+#' y <- seq(from = -90, to = 90, length.out = 50)
+#' PlotStereoMap(data, x, y, latlims = c(60, 90), brks = 50,
+#'               toptitle = "This is the title")
+#'
 #'@import mapproj
 #'@importFrom grDevices dev.cur dev.new dev.off gray
 #'@importFrom stats median
@@ -603,6 +602,8 @@ PlotStereoMap <- function(var, lon, lat, varu = NULL, varv = NULL, latlims = c(6
     layout(matrix(1:2, ncol = 2, nrow = 1), widths = c(8, 2))
   }
   # Load the user parameters
+  oldpar <- par(no.readonly = TRUE)
+  on.exit(par(oldpar))
   par(userArgs)
   par(mar = margins, las = 0)
   coast <- map("world", interior = FALSE, projection = "stereographic", 
