@@ -11,23 +11,22 @@
 #'The p-value and significance test are optionally provided by an one-sided 
 #'Fisher test or Random Walk test.\cr
 #'
-#'@param exp A named numeric array of experimental data which contains at least
-#'  time dimension (time_dim). It can also be a vector with the same length as
-#'  'obs', then the vector will automatically be 'time_dim'.
-#'@param obs A named numeric array of observational data which contains at least
-#'  time dimension (time_dim). The dimensions should be the same as parameter
-#'  'exp' except the length of 'dat_dim' and 'memb_dim' dimension. It can also 
-#'  be a vector with the same length as 'exp', then the vector will 
-#'  automatically be 'time_dim'.
-#'@param ref A named numerical array of the reference forecast data with at 
-#'  least time dimension, or 0 (typical climatological forecast) or 1 
-#'  (normalized climatological forecast). If it is an array, the dimensions must
-#'  be the same as 'exp' except 'memb_dim' and 'dat_dim'. If there is only one
-#'  reference dataset, it should not have dataset dimension. If there is 
-#'  corresponding reference for each experiment, the dataset dimension must 
-#'  have the same length as in 'exp'. If 'ref' is NULL, the typical 
-#'  climatological forecast is used as reference forecast (equivalent to 0.)
-#'  The default value is NULL.
+#'@param exp A numerical array with named dimensions of experimental data which
+#'  contains at least time dimension (time_dim). It can also be a vector with
+#'  the same length as obs', then the vector will automatically be 'time_dim'.
+#'@param obs A numerical array with named dimensions of observational data which
+#'  contains at least time dimension (time_dim). The dimensions should be the
+#'  same as parameter exp' except the length of 'dat_dim' and 'memb_dim'
+#'  dimension. It can also be a vector with the same length as 'exp', then the
+#'  vector will automatically be 'time_dim'.
+#'@param ref A numerical array with named dimensions of the reference forecast
+#'  data with at least time dimension, or a single numeric value. If it is an
+#'  array, the dimensions must be the same as 'exp' except 'memb_dim' and
+#'  'dat_dim'. If there is only one reference dataset, it should not have
+#'  dataset dimension. If there is a corresponding reference for each experiment,
+#'  the dataset dimension must have the same length as in 'exp'. If 'ref' is
+#'  NULL, the climatological forecast is calculated from the mean of 'obs' and
+#'  used as reference forecast. The default value is NULL.
 #'@param dat_dim A character string indicating the name of dataset (nobs/nexp) 
 #'  dimension. The default value is NULL.
 #'@param time_dim A character string indicating the name of dimension along  
@@ -77,12 +76,12 @@
 #'}
 #'
 #'@examples
-#'# Load sample data as in Load() example:
-#'example(Load)
-#'clim <- Clim(sampleData$mod, sampleData$obs)
-#'ano_exp <- Ano(sampleData$mod, clim$clim_exp)
-#'ano_obs <- Ano(sampleData$obs, clim$clim_obs)
-#'rmsss <- RMSSS(ano_exp, ano_obs, dat_dim = 'dataset', memb_dim = 'member')
+#' # Load sample data as in Load() example:
+#' example(LoadSampleData)
+#' clim <- Clim(sampleData$mod, sampleData$obs)
+#' ano_exp <- Ano(sampleData$mod, clim$clim_exp)
+#' ano_obs <- Ano(sampleData$obs, clim$clim_obs)
+#' rmsss <- RMSSS(ano_exp, ano_obs, dat_dim = 'dataset', memb_dim = 'member')
 #'
 #' set.seed(1)
 #' exp1 <- array(rnorm(30), dim = c(dataset = 2, time = 3, memb = 5))
@@ -132,27 +131,6 @@ RMSSS <- function(exp, obs, ref = NULL, time_dim = 'sdate', dat_dim = NULL,
       any(is.null(names(dim(obs)))) | any(nchar(names(dim(obs))) == 0)) {
     stop("Parameter 'exp' and 'obs' must have dimension names.")
   }
-  if (!is.null(ref)) {
-    if (!is.numeric(ref)) {
-      stop("Parameter 'ref' must be numeric.")
-    }
-    if (is.array(ref)) {
-      if (any(is.null(names(dim(ref)))) | any(nchar(names(dim(ref))) == 0)) {
-        stop("Parameter 'ref' must have dimension names.")
-      }
-    } else if (length(ref) != 1 | !all(ref %in% c(0, 1))) {
-      stop("Parameter 'ref' must be a numeric array or number 0 or 1.")
-    }
-  } else {
-    ref <- 0
-    .warning("If a reference dataset is not provided (ref = NULL), the default ", 
-            "value for the climatology is 0 and RMSSS results will only be ",
-            "correct if 'exp' and 'obs' are anomalies. Provide a non-null ",
-            "'ref' for full-field data.")
-  }
-  if (!is.array(ref)) { # 0 or 1
-    ref <- array(data = ref, dim = dim(exp))
-  }
 
   ## time_dim
   if (!is.character(time_dim) | length(time_dim) > 1) {
@@ -264,16 +242,39 @@ RMSSS <- function(exp, obs, ref = NULL, time_dim = 'sdate', dat_dim = NULL,
     stop("Parameter 'exp' and 'obs' must have same length of ",
          "all dimensions except 'dat_dim' and 'memb_dim'.")
   }
-  
+  ## ref
+  if (!is.null(ref)) {
+    if (!is.numeric(ref)) {
+      stop("Parameter 'ref' must be numeric.")
+    }
+    if (is.array(ref)) {
+      if (any(is.null(names(dim(ref)))) | any(nchar(names(dim(ref))) == 0)) {
+        stop("Parameter 'ref' must have dimension names.")
+      }
+    } else {
+      if (length(ref) != 1) {
+        stop("Parameter 'ref' must be a numeric array or a single numeric value.")
+      }
+      ref <- array(data = ref, dim = dim(exp)) # 'ref' is a single numeric value
+    }
+  } else {
+    ref <- MeanDims(data = obs, dims = time_dim, na.rm = TRUE, drop = TRUE)
+    if (!is.array(ref)) {
+      ref <- array(data = ref, dim = dim(exp))
+    } else {
+      ref <- InsertDim(data = ref, posdim = which(names(dim(exp)) == time_dim),
+                       lendim = as.numeric(dim(exp)[time_dim]), name = time_dim)
+    }
+  }
   name_ref <- sort(names(dim(ref)))
   if (!is.null(memb_dim) && memb_dim %in% name_ref) {
     name_ref <- name_ref[-which(name_ref == memb_dim)]
   }
   if (!is.null(dat_dim)) {
     if (dat_dim %in% name_ref) {
-      if (!identical(dim(exp)[dat_dim], dim(ref)[dat_dim])) {
+      if (!identical(dim(obs)[dat_dim], dim(ref)[dat_dim])) {
         stop("If parameter 'ref' has dataset dimension, it must be ", 
-             "equal to dataset dimension of 'exp'.")
+             "equal to dataset dimension of 'obs'.")
       }
       name_ref <- name_ref[-which(name_ref == dat_dim)]
     }
@@ -360,8 +361,8 @@ RMSSS <- function(exp, obs, ref = NULL, time_dim = 'sdate', dat_dim = NULL,
   # ref: [sdate, (dat)] or NULL
 
   if (is.null(ref)) {
-    ref <- array(data = 0, dim = dim(obs))
-  } else if (identical(ref, 0) | identical(ref, 1)) {
+    ref <- array(data = mean(obs), dim = dim(obs))
+  } else if (is.numeric(ref) & length(ref)==1) {
     ref <- array(ref, dim = dim(exp))
   }
 
