@@ -997,63 +997,6 @@
   }
 }
 
-.LoadSampleData <- function(var, exp = NULL, obs = NULL, sdates, 
-                            nmember = NULL, nmemberobs = NULL, 
-                            nleadtime = NULL, leadtimemin = 1, 
-                            leadtimemax = NULL, storefreq = 'monthly', 
-                            sampleperiod = 1, lonmin = 0, lonmax = 360, 
-                            latmin = -90, latmax = 90, output = 'areave', 
-                            method = 'conservative', grid = NULL, 
-                            maskmod = vector("list", 15), 
-                            maskobs = vector("list", 15), 
-                            configfile = NULL, suffixexp = NULL, 
-                            suffixobs = NULL, varmin = NULL, varmax = NULL, 
-                            silent = FALSE, nprocs = NULL) {
-  ## This function loads and selects sample data stored in sampleMap and 
-  ## sampleTimeSeries and is used in the examples instead of Load() so as
-  ## to avoid nco and cdo system calls and computation time in the stage 
-  ## of running examples in the CHECK process on CRAN.
-  selected_start_dates <- match(sdates, c('19851101', '19901101', '19951101', 
-                                          '20001101', '20051101'))
-  start_dates_position <- 3
-  lead_times_position <- 4
-
-  if (output == 'lonlat') {
-    sampleData <- s2dv::sampleMap
-    if (is.null(leadtimemax)) {
-      leadtimemax <- dim(sampleData$mod)[lead_times_position]
-    }
-    selected_lead_times <- leadtimemin:leadtimemax
-
-    dataOut <- sampleData
-    dataOut$mod <- sampleData$mod[, , selected_start_dates, selected_lead_times, , ]
-    dataOut$obs <- sampleData$obs[, , selected_start_dates, selected_lead_times, , ]
-  } else if (output == 'areave') {
-    sampleData <- s2dv::sampleTimeSeries
-    if (is.null(leadtimemax)) {
-      leadtimemax <- dim(sampleData$mod)[lead_times_position]
-    }
-    selected_lead_times <- leadtimemin:leadtimemax
-
-    dataOut <- sampleData
-    dataOut$mod <- sampleData$mod[, , selected_start_dates, selected_lead_times]
-    dataOut$obs <- sampleData$obs[, , selected_start_dates, selected_lead_times]
-  }
-
-  dims_out <- dim(sampleData$mod)
-  dims_out[start_dates_position] <- length(selected_start_dates)
-  dims_out[lead_times_position] <- length(selected_lead_times)
-  dim(dataOut$mod) <- dims_out
-
-  dims_out <- dim(sampleData$obs)
-  dims_out[start_dates_position] <- length(selected_start_dates)
-  dims_out[lead_times_position] <- length(selected_lead_times)
-  dim(dataOut$obs) <- dims_out
-
-  invisible(list(mod = dataOut$mod, obs = dataOut$obs, 
-                 lat = dataOut$lat, lon = dataOut$lon))
-}
-
 .ConfigGetDatasetInfo <- function(matching_entries, table_name) {
   # This function obtains the information of a dataset and variable pair,
   # applying all the entries that match in the configuration file.
